from setuptools import setup, find_packages

def read_requirements(file):
    """Read requirements file and return a list of dependencies."""
    with open(file, encoding="utf-8") as f:
        return f.read().splitlines()

def read_file(file):
    """Read a file and return its contents."""
    with open(file, encoding="utf-8") as f:
        return f.read().strip()

def get_version():
    """Get version from __init__.py"""
    with open('helpr/__init__.py', 'r') as f:
        for line in f:
            if line.startswith('__version__'):
                delim = '"' if '"' in line else "'"
                return line.split(delim)[1]
    return '0.0.0'

# Read metadata file
long_description = read_file("README.rst")
requirements = read_requirements("requirements.txt")
version = get_version()

setup(
    name="helpr",
    version=version,
    author="Clinikally",
    author_email="puneetsrivastava@clinikally.com",
    url="https://github.com/clinikally/helpr",
    description="A Python package to help you with your daily tasks",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    license="MIT license",
    packages=find_packages(exclude=["tests", "docs"]),
    install_requires=requirements,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)